pub struct Message {
pub bytes: Vec<u8>,
pub metadata: HashMap<String, Value>,
pub message_type: MessageType,
pub stream_id: Option<String>,
}Expand description
Message is the uniform struct utilized within all modules of fiddler.
let content = "This is a message being processed";
let message = Message{
bytes: content.as_bytes().into(),
..Default::default()
};Fields
bytes: Vec<u8>raw bytes of of the message to be collected, processed, and sent
metadata: HashMap<String, Value>metadata about the message
message_type: MessageTypeSpecifies the message type. If MessageType::BeginStream or MessageType::EndStream is provided, no processing of the event will take place, but the callback will be called when all child messages have been processed. This gives modules the ability to tier callback actions. Such as a module that receives a file from a queue and then processes all the lines in said file. Each line will be its own Message; where the stream callback will delete the original message once all lines are processed.
stream_id: Option<String>[Optional] Specifies the stream_id of the associated stream of messages with a shared callback